==> microsoft_kiota_serialization_form-0.1.0.tar.gz: microsoft_kiota_serialization_form-0.1.0/README.md <==
# Microsoft Kiota URI Form Encoded Serialization Library for Python
[![PyPI version](https://badge.fury.io/py/microsoft-kiota-serialization-form.svg)](https://badge.fury.io/py/microsoft-kiota-serialization-form)
[![CI Actions Status](https://github.com/microsoft/kiota-serialization-form-python/actions/workflows/build.yml/badge.svg?branch=main)](https://github.com/microsoft/kiota-serialization-form-python/actions)
[![Downloads](https://pepy.tech/badge/microsoft-kiota-serialization-form)](https://pepy.tech/project/microsoft-kiota-serialization-form)

The Form Serialization Library for Python is the python `application/x-www-form-urlencoded` serialization library implementation.

A [Kiota](https://github.com/microsoft/kiota) generated project will need a reference to a form serialization package to handle `application/x-www-form-urlencoded payloads` from a supporting API endpoint.

Read more about Kiota [here](https://github.com/microsoft/kiota/blob/main/README.md).

## Using the Microsoft Kiota URI Form Encoded Serialization Library

In order to use this library, install the package by running:

```cmd
pip install microsoft-kiota-serialization-form
```

## Contributing

This project welcomes contributions and suggestions.  Most contributions require you to agree to a
Contributor License Agreement (CLA) declaring that you have the right to, and actually do, grant us
the rights to use your contribution. For details, visit https://cla.opensource.microsoft.com.

When you submit a pull request, a CLA bot will automatically determine whether you need to provide
a CLA and decorate the PR appropriately (e.g., status check, comment). Simply follow the instructions
provided by the bot. You will only need to do this once across all repos using our CLA.

This project has adopted the [Microsoft Open Source Code of Conduct](https://opensource.microsoft.com/codeofconduct/).
For more information see the [Code of Conduct FAQ](https://opensource.microsoft.com/codeofconduct/faq/) or
contact [opencode@microsoft.com](mailto:opencode@microsoft.com) with any additional questions or comments.

## Trademarks

This project may contain trademarks or logos for projects, products, or services. Authorized use of Microsoft 
trademarks or logos is subject to and must follow 
[Microsoft's Trademark & Brand Guidelines](https://www.microsoft.com/en-us/legal/intellectualproperty/trademarks/usage/general).
Use of Microsoft trademarks or logos in modified versions of this project must not cause confusion or imply Microsoft sponsorship.
Any use of third-party trademarks or logos are subject to those third-party's policies.

==> microsoft_kiota_serialization_form-1.8.0.tar.gz: microsoft_kiota_serialization_form-1.8.0/README.md <==
# Microsoft Kiota URI Form Encoded Serialization Library for Python

[![PyPI version](https://badge.fury.io/py/microsoft-kiota-serialization-form.svg)](https://badge.fury.io/py/microsoft-kiota-serialization-form)
[![Downloads](https://pepy.tech/badge/microsoft-kiota-serialization-form)](https://pepy.tech/project/microsoft-kiota-serialization-form)

The Form Serialization Library for Python is the python `application/x-www-form-urlencoded` serialization library implementation.

A [Kiota](https://github.com/microsoft/kiota) generated project will need a reference to a form serialization package to handle `application/x-www-form-urlencoded payloads` from a supporting API endpoint.

Read more about Kiota [here](https://github.com/microsoft/kiota/blob/main/README.md).

## Using the Microsoft Kiota URI Form Encoded Serialization Library

In order to use this library, install the package by running:

```cmd
pip install microsoft-kiota-serialization-form
```

## Contributing

This project welcomes contributions and suggestions.  Most contributions require you to agree to a
Contributor License Agreement (CLA) declaring that you have the right to, and actually do, grant us
the rights to use your contribution. For details, visit <https://cla.opensource.microsoft.com>.

When you submit a pull request, a CLA bot will automatically determine whether you need to provide
a CLA and decorate the PR appropriately (e.g., status check, comment). Simply follow the instructions
provided by the bot. You will only need to do this once across all repos using our CLA.

This project has adopted the [Microsoft Open Source Code of Conduct](https://opensource.microsoft.com/codeofconduct/).
For more information see the [Code of Conduct FAQ](https://opensource.microsoft.com/codeofconduct/faq/) or
contact [opencode@microsoft.com](mailto:opencode@microsoft.com) with any additional questions or comments.

## Trademarks

This project may contain trademarks or logos for projects, products, or services. Authorized use of Microsoft
trademarks or logos is subject to and must follow
[Microsoft's Trademark & Brand Guidelines](https://www.microsoft.com/en-us/legal/intellectualproperty/trademarks/usage/general).
Use of Microsoft trademarks or logos in modified versions of this project must not cause confusion or imply Microsoft sponsorship.
Any use of third-party trademarks or logos are subject to those third-party's policies.
